@@ -265,7 +265,7 @@ class Application(Adw.Application):
 
     def __on_quit(self) -> None:
         if self.__window:
-            self.__window.close()
+            self.__window.cleanup_and_close()
 
     def __on_create_note(self) -> None:
         self.activate()
