@@ -113,7 +113,9 @@ class Index(Adw.BreakpointBin):
         controller.connect("key-pressed", self.__on_index_key_pressed)
         self.add_controller(controller)
 
-        self._search_header_bar.connect("changed", lambda _o: self.__apply_search())
+        self._search_header_bar.connect(
+            "changed", lambda _o: self.__apply_search(invalidate_scroll_and_expansion=True)
+        )
 
         self.__config_manager.connect_changed(
             ConfigManager.INDEX_CATEGORY_STYLE,
@@ -718,20 +720,24 @@ class Index(Adw.BreakpointBin):
         model = self.__note_manager.initiate_search_model()
         self._note_list.populate_search(model)
 
-    def __apply_search(self) -> None:
+    def __apply_search(self, invalidate_scroll_and_expansion: bool = False) -> None:
         if not self.__searching():
             return
 
         # If trying to search without caching completed delay the search
         if self.__note_manager.search_model is None:
-            GLib.timeout_add(500, self.__apply_search)
+            GLib.timeout_add(500, self.__apply_search, invalidate_scroll_and_expansion)
             logging.debug("Delaying search due to model not ready")
             return
 
-        result = self._search_header_bar.search()
+        show_all = (
+            not invalidate_scroll_and_expansion and self._note_list.showing_expanded_search_set
+        )
+        result = self._search_header_bar.search(show_all)
         if result == IndexSearchState.RESULTS:
             self._stack.set_visible_child(self._note_list_scroll)
-            self._note_list_scroll.get_vadjustment().set_value(0)
+            if invalidate_scroll_and_expansion:
+                self._note_list_scroll.get_vadjustment().set_value(0)
         elif result == IndexSearchState.EMPTY:
             self._stack.set_visible_child(self._search_empty)
         elif result == IndexSearchState.NO_TERM:
