@@ -326,17 +326,18 @@ class NoteManager(GObject.Object):
         self.__category_filtered_model.invalidate_filter(category)
         self.__favourites_model.invalidate_filter()
 
-        now = datetime.now()
-        today_dt = now.replace(hour=0, minute=0, second=0)
+        now = get_now()
+        today_dt = now.replace(hour=0, minute=0, second=0, microsecond=0)
         today = today_dt.timestamp()
         yesterday = (today_dt - timedelta(days=1)).timestamp()
         monday = (today_dt - timedelta(days=now.weekday())).timestamp()
         start_of_month = now.replace(hour=0, minute=0, second=0, day=1).timestamp()
-        start_of_last_month = NoteManager.get_start_of_last_month()
+        start_of_last_month = get_start_of_last_month()
 
         self.__today_model.invalidate_filter(time_min=today)
         self.__yesterday_model.invalidate_filter(time_min=yesterday, time_max=today)
         self.__week_model.invalidate_filter(time_min=monday, time_max=yesterday)
+
         # If today is the first day of the month, or if the start of the week is earlier than the
         # start of the month don't show the rest of this month. Also ensures last month doesn't
         # have overlap content with the week.
@@ -345,8 +346,11 @@ class NoteManager(GObject.Object):
         # Account for yesterday when setting rest of month end point
         month_end = yesterday if yesterday < monday else monday
         self.__month_model.invalidate_filter(time_min=start_of_month, time_max=month_end)
+
+        # Account for yesterday when setting last month end point
+        last_month_end = yesterday if yesterday < start_of_month else start_of_month
         self.__last_month_model.invalidate_filter(
-            time_min=start_of_last_month, time_max=start_of_month
+            time_min=start_of_last_month, time_max=last_month_end
         )
 
         older_loaded = False
@@ -366,7 +370,7 @@ class NoteManager(GObject.Object):
         if self.__older_notes_model is None:
             return
 
-        start_of_last_month = NoteManager.get_start_of_last_month()
+        start_of_last_month = get_start_of_last_month()
         self.__older_notes_model.invalidate_filter(time_max=start_of_last_month)
 
     def get_deleted_notes_pending_undo(self) -> list[Note]:
@@ -522,16 +526,20 @@ class NoteManager(GObject.Object):
         else:
             self.__db.persist_note_editable(note)
 
-    @staticmethod
-    def get_start_of_last_month() -> float:
-        now = datetime.now()
-        start_of_month_dt = now.replace(hour=0, minute=0, second=0, day=1)
-        if start_of_month_dt.month > 1:
-            start_of_last_month = start_of_month_dt.replace(
-                month=start_of_month_dt.month - 1
-            ).timestamp()
-        else:
-            start_of_last_month = start_of_month_dt.replace(
-                month=12, year=start_of_month_dt.year - 1
-            ).timestamp()
-        return start_of_last_month
+
+def get_start_of_last_month() -> float:
+    now = get_now()
+    start_of_month_dt = now.replace(hour=0, minute=0, second=0, day=1)
+    if start_of_month_dt.month > 1:
+        start_of_last_month = start_of_month_dt.replace(
+            month=start_of_month_dt.month - 1
+        ).timestamp()
+    else:
+        start_of_last_month = start_of_month_dt.replace(
+            month=12, year=start_of_month_dt.year - 1
+        ).timestamp()
+    return start_of_last_month
+
+
+def get_now() -> datetime:
+    return datetime.now()
