@@ -132,7 +132,7 @@ class SyncManager(GObject.Object):
             return
 
         if self.__lock.locked:
-            self.__sync_requested_while_active = False
+            self.__sync_requested_while_active = True
             return
 
         if self.__waiting_timeout:
@@ -218,7 +218,7 @@ class SyncManager(GObject.Object):
         self.__waiting_timeout = None
 
         if self.__lock.locked:
-            self.__sync_requested_while_active = False
+            self.__sync_requested_while_active = True
             return
 
         GLib.idle_add(self.emit, "started")
@@ -266,6 +266,9 @@ class SyncManager(GObject.Object):
             notes, remote_ids_from_db, fetching_all
         )
 
+        # Remove duplicate updates caused by eg. ignored No-Cache headers
+        remote_upd = self.__filter_out_false_updates(remote_upd)
+
         # Pre-processing for remote updates to notes which have local changes
         remote_upd = self.__preprocess_remote_updates_for_locally_modified(remote_upd)
 
@@ -342,25 +345,74 @@ class SyncManager(GObject.Object):
 
         return (create, update)
 
+    def __filter_out_false_updates(self, updates_in: list[dict]) -> list[dict]:
+        updates_out = []
+        for remote_note_dict in updates_in:
+            # Fetch note
+            local_note = self.__note_manager.fetch_note_by_remote_id(remote_note_dict["id"])
+            if local_note is None:
+                logging.warning(
+                    f"Failed to find local note with remote id '{remote_note_dict['id']}'"
+                )
+                continue
+
+            # Handle possible false updates from misbehaving proxies etc
+            remote_note = Note.from_nextcloud(remote_note_dict)
+            if local_note.etag_is_recent(remote_note.etag):
+                if local_note.identical_non_sync_meta(remote_note):
+                    # The update from the server is an ETag from a recent push with no metadata
+                    # changes, we're likely receiving cached or otherwise old content. Ignore the
+                    # update.
+                    logging.debug(
+                        f"Remote note appears to be a past push, etag '{remote_note.etag}'"
+                    )
+                    # Skip adding for further processing
+                    continue
+                else:
+                    if not local_note.content_loaded:
+                        self.__db.populate_note_content(local_note)
+                    if local_note.dirty and local_note.content == remote_note.content:
+                        # If our local note has changed for something other than content we
+                        # possibly have a real conflict. Allow falling through to that.
+                        logging.debug(
+                            "Note update received for locally modified note with no etag change "
+                            "and no content change"
+                        )
+                    else:
+                        # Possibly just a remote metadata change, but let's ignore the
+                        # content to be safe
+                        logging.debug("Note received with past etag but meta update")
+                        remote_note_dict["ignore-content"] = True
+
+            updates_out.append(remote_note_dict)
+
+        return updates_out
+
     def __preprocess_remote_updates_for_locally_modified(
         self, updates_in: list[dict]
     ) -> list[dict]:
         updates_out = []
-        for sync_note in updates_in:
+        for remote_note_dict in updates_in:
             # Fetch note
-            note = self.__note_manager.fetch_note_by_remote_id(sync_note["id"])
-            if note is None:
-                logging.warning(f"Failed to fetch local note by remote id '{sync_note['id']}'")
+            local_note = self.__note_manager.fetch_note_by_remote_id(remote_note_dict["id"])
+            if local_note is None:
+                logging.warning(
+                    f"Failed to find local note with remote id '{remote_note_dict['id']}'"
+                )
                 continue
 
+            # Duplicate filtering can flag notes for which content changes should be ignored
+            ignore_content_change = "ignore-content" in remote_note_dict
+
             # Handle local note with changes
-            if note.dirty:
-                update_note = Note.from_nextcloud(sync_note)
-                if not note.content_loaded:
-                    self.__db.populate_note_content(note)
-                if note.identical_excepting_sync_meta(update_note):
+            if local_note.dirty and not ignore_content_change:
+                remote_note = Note.from_nextcloud(remote_note_dict)
+                new_dirty = False
+                if not local_note.content_loaded:
+                    self.__db.populate_note_content(local_note)
+                if local_note.identical_excepting_sync_meta(remote_note):
                     logging.info("Applying remote sync meta to otherwise identical note")
-                elif self.__conflict_is_recent_failed_push(note, update_note):
+                elif self.__conflict_is_recent_failed_push(local_note, remote_note):
                     # The remote note is an older version of the local note. We attempted to sync
                     # it but didn't receive an ack and as a result our local etag is out of date.
                     # So we update the etag and ignore everything else.
@@ -368,23 +420,23 @@ class SyncManager(GObject.Object):
                         "Avoiding conflict as remote note with updated etag appears to be "
                         "a failed past push"
                     )
-                    note.etag = update_note.etag
-                    self.__db.persist_note_etag(note)
+                    local_note.etag = remote_note.etag
+                    self.__db.persist_note_etag(local_note)
                     # Skip adding for further processing
                     continue
                 else:
                     logging.info(
-                        f"Sync. conflict, note '{note.title}' was modified locally and updated "
-                        "remotely"
+                        f"Sync. conflict, note '{local_note.title}' was modified locally and "
+                        "updated remotely"
                     )
-                    GLib.idle_add(self.emit, "note-conflict", note)
+                    GLib.idle_add(self.emit, "note-conflict", local_note)
                     # Duplicate existing note
-                    GLib.idle_add(self.__duplicate_note_for_sync_conflict, note)
+                    GLib.idle_add(self.__duplicate_note_for_sync_conflict, local_note)
 
-                note.dirty = False
-                self.__db.persist_note_dirty(note)
+                local_note.dirty = new_dirty
+                self.__db.persist_note_dirty(local_note)
 
-            updates_out.append(sync_note)
+            updates_out.append(remote_note_dict)
 
         return updates_out
 
@@ -524,7 +576,7 @@ class SyncManager(GObject.Object):
                     self.emit, "remote-category-sanitised", previous_category, remote_category
                 )
         else:
-            logging.info(f"Note sync failed (with status code {sync_result.status_code})")
+            logging.info(f"Note push failed (with status code {sync_result.status_code})")
 
             if sync_result.sent_content is not None:
                 # Track this failed push so that it can be used to avoid possible conflicts if the
