@@ -88,7 +88,7 @@ class Window(Adw.ApplicationWindow):
             "initial-load-complete", lambda _o: self.__on_initial_load_from_db_complete()
         )
 
-        self.connect("close-request", lambda _o: self.__cleanup_and_close())
+        self.connect("close-request", lambda _o: self.cleanup_and_close())
         self.connect("notify::visible-dialog", lambda _o, _v: self.__update_for_visible_dialogs())
 
         (width, height) = self.__config_manager.get_window_size()
@@ -102,6 +102,17 @@ class Window(Adw.ApplicationWindow):
         self._index.active = True
         self._editor.active = False
 
+    def cleanup_and_close(self) -> None:
+        """Cleanup for exit."""
+        if self._editor.editing:
+            self.__note_manager.apply_any_server_sanitised_title(self._editor.current_note)
+            self.__note_manager.persist_note_sync(self._editor.current_note)
+        self.__sync_manager.close()
+        if not self.is_fullscreen():
+            self.__config_manager.set_window_size(self.get_width(), self.get_height())
+        self.__config_manager.first_start = False
+        self.close()
+
     @GObject.Property(type=bool, default=False)
     def using_keyboard_navigation(self) -> bool:
         return self.__using_keyboard_navigation
@@ -137,7 +148,7 @@ class Window(Adw.ApplicationWindow):
         app.set_accels_for_action("win.fullscreen", ["F11"])
 
         action = Gio.SimpleAction.new("close")
-        action.connect("activate", lambda _o, _v: self.__cleanup_and_close())
+        action.connect("activate", lambda _o, _v: self.cleanup_and_close())
         action_group.add_action(action)
         app.set_accels_for_action("win.close", ["<Control>w"])
         self.__close_window_action = action
@@ -335,12 +346,3 @@ class Window(Adw.ApplicationWindow):
         self._index.update_for_dialog_visibility(visible)
         self._editor.update_for_dialog_visibility(visible)
         self.__close_window_action.set_enabled(not visible)
-
-    def __cleanup_and_close(self) -> None:
-        if self._editor.editing:
-            self.__note_manager.apply_any_server_sanitised_title(self._editor.current_note)
-        self.__sync_manager.close()
-        if not self.is_fullscreen():
-            self.__config_manager.set_window_size(self.get_width(), self.get_height())
-        self.__config_manager.first_start = False
-        self.close()
